library(teachingApps)
<<<<<<< HEAD
pacman::p_load(shiny, plotly)
=======
pacman::p_load(shiny, plotly)
dirs <- list.dirs(system.file('examples',package = 'shiny'), recursive = F)
>>>>>>> 725cde6e3cf3d4f401624356a8d30a138358fcc1
